@@ -100,6 +100,7 @@ class OverkizCommand(str, Enum):
     SET_PASS_APC_OPERATING_MODE = "setPassAPCOperatingMode"
     SET_PEDESTRIAN_POSITION = "setPedestrianPosition"
     SET_RGB = "setRGB"
+    SET_SCHEDULING_TYPE = "setSchedulingType"
     SET_SECURED_POSITION_TEMPERATURE = "setSecuredPositionTemperature"
     SET_TARGET_ALARM_MODE = "setTargetAlarmMode"
     SET_TARGET_TEMPERATURE = "setTargetTemperature"
@@ -116,6 +117,7 @@ class OverkizCommand(str, Enum):
     UNINSTALLED = "uninstalled"
     UNLOCK = "unlock"
     UP = "up"
+    UPDATE = "update"
     WINK = "wink"
 
 
@@ -158,6 +160,8 @@ class OverkizCommandParam(str, Enum):
     ENERGY_DEMAND_STATUS = "energyDemandStatus"
     EXTERNAL = "external"
     EXTERNAL_GATEWAY = "externalGateway"
+    EXTERNAL_SCHEDULING = "externalScheduling"
+    EXTERNAL_SETPOINT = "externalSetpoint"
     FAN = "fan"
     FREE = "free"
     FREEZE_MODE = "freezeMode"
