@@ -26,8 +26,12 @@ class OverkizState(str, Enum):
     CORE_BATTERY = "core:BatteryState"
     CORE_BATTERY_LEVEL = "core:BatteryLevelState"
     CORE_BLUE_COLOR_INTENSITY = "core:BlueColorIntensityState"
+    CORE_BOOST_ELECTRIC_POWER_CONSUMPTION = "core:BoostElectricPowerConsumptionState"
+    CORE_BOOST_END_DATE = "core:BoostEndDateState"
     CORE_BOOST_MODE_DURATION = "core:BoostModeDurationState"
     CORE_BOOST_ON_OFF = "core:BoostOnOffState"
+    CORE_BOOST_START_DATE = "core:BoostStartDateState"
+    CORE_BOTTOM_TANK_WATER_TEMPERATURE = "core:BottomTankWaterTemperatureState"
     CORE_CLOSURE = "core:ClosureState"
     CORE_CLOSURE_OR_ROCKER_POSITION = "core:ClosureOrRockerPositionState"
     CORE_CLOUD_DEVICE_STATUS = "core:CloudDeviceStatusState"
@@ -47,6 +51,7 @@ class OverkizState(str, Enum):
     CORE_CONSUMPTION_TARIFF8 = "core:ConsumptionTariff8State"
     CORE_CONSUMPTION_TARIFF9 = "core:ConsumptionTariff9State"
     CORE_CONTACT = "core:ContactState"
+    CORE_CONTROL_WATER_TARGET_TEMPERATURE = "core:ControlWaterTargetTemperatureState"
     CORE_CO_CONCENTRATION = "core:COConcentrationState"
     CORE_DEPLOYMENT = "core:DeploymentState"
     CORE_DEROGATED_TARGET_TEMPERATURE = "core:DerogatedTargetTemperatureState"
@@ -68,6 +73,7 @@ class OverkizState(str, Enum):
     CORE_GAS_DETECTION = "core:GasDetectionState"
     CORE_GREEN_COLOR_INTENSITY = "core:GreenColorIntensityState"
     CORE_HEATING_ON_OFF = "core:HeatingOnOffState"
+    CORE_HEATING_STATUS = "core:HeatingStatusState"
     CORE_HEATING_TARGET_TEMPERATURE = "core:HeatingTargetTemperatureState"
     CORE_INTRUSION = "core:IntrusionState"
     CORE_LEVEL = "core:LevelState"
@@ -82,6 +88,7 @@ class OverkizState(str, Enum):
     )
     CORE_MAXIMUM_TEMPERATURE = "core:MaximumTemperatureState"
     CORE_MEMORIZED_1_POSITION = "core:Memorized1PositionState"
+    CORE_MIDDLE_WATER_TEMPERATURE_IN = "core:MiddleWaterTemperatureInState"
     CORE_MINIMAL_SHOWER_MANUAL_MODE = "core:MinimalShowerManualModeState"
     CORE_MINIMAL_TEMPERATURE_MANUAL_MODE = "core:MinimalTemperatureManualModeState"
     CORE_MINIMUM_HEATING_TARGET_TEMPERATURE = (
@@ -92,6 +99,7 @@ class OverkizState(str, Enum):
     CORE_MOVING = "core:MovingState"
     CORE_NAME = "core:NameState"
     CORE_NUMBER_OF_SHOWER_REMAINING = "core:NumberOfShowerRemainingState"
+    CORE_NUMBER_OF_TANK = "core:NumberOfTankState"
     CORE_OCCUPANCY = "core:OccupancyState"
     CORE_ON_OFF = "core:OnOffState"
     CORE_OPEN_CLOSED = "core:OpenClosedState"
@@ -100,9 +108,11 @@ class OverkizState(str, Enum):
     CORE_OPEN_CLOSED_UNKNOWN = "core:OpenClosedUnknownState"
     CORE_OPERATING_MODE = "core:OperatingModeState"
     CORE_PEDESTRIAN_POSITION = "core:PedestrianPositionState"
+    CORE_POWER_HEAT_ELECTRICAL_IN = "core:PowerHeatElectricalInState"
     CORE_POWER_SUPPLY_UP_DOWN = "core:PowerSupplyUpDownState"
     CORE_PRIORITY_LOCK_TIMER = "core:PriorityLockTimerState"
     CORE_PRODUCT_MODEL_NAME = "core:ProductModelNameState"
+    CORE_PROGRAMING_AVAILABLE_STATE = "core:ProgrammingAvailableState"
     CORE_RAIN = "core:RainState"
     CORE_RED_COLOR_INTENSITY = "core:RedColorIntensityState"
     CORE_RELATIVE_HUMIDITY = "core:RelativeHumidityState"
@@ -115,6 +125,7 @@ class OverkizState(str, Enum):
     CORE_SLATS_ORIENTATION = "core:SlatsOrientationState"
     CORE_SMOKE = "core:SmokeState"
     CORE_STATUS = "core:StatusState"
+    CORE_STOP_RELAUNCH = "core:StopRelaunchState"
     CORE_SUN_ENERGY = "core:SunEnergyState"
     CORE_TARGET_CLOSURE = "core:TargetClosureState"
     CORE_TARGET_DWH_TEMPERATURE = "core:TargetDHWTemperatureState"
@@ -170,10 +181,27 @@ class OverkizState(str, Enum):
     IO_VENTILATION_CONFIGURATION_MODE = "io:VentilationConfigurationModeState"
     IO_VENTILATION_MODE = "io:VentilationModeState"
     IO_VIBRATION_DETECTED = "io:VibrationDetectedState"
+    MODBUSLINK_ANTI_LEGIONELLOSIS = "modbuslink:AntiLegionellosisState"
     MODBUSLINK_DHW_ABSENCE_MODE = "modbuslink:DHWAbsenceModeState"
     MODBUSLINK_DHW_BOOST_MODE = "modbuslink:DHWBoostModeState"
+    MODBUSLINK_DHW_CAPACITY = "modbuslink:DHWCapacityState"
+    MODBUSLINK_DHW_ERROR = "modbuslink:DHWErrorState"
     MODBUSLINK_DHW_MODE = "modbuslink:DHWModeState"
+    MODBUSLINK_ELECTRIC_BOOSTER_OPERATING_TIME = (
+        "modbuslink:ElectricBoosterOperatingTimeState"
+    )
+    MODBUSLINK_HEAT_PUMP_OPERATING_TIME = "modbuslink:HeatPumpOperatingTimeState"
+    MODBUSLINK_IHM_TYPE = "modbuslink:IHMTypeState"
+    MODBUSLINK_MANUFACTURER = "modbuslink:ManufacturerState"
     MODBUSLINK_MIDDLE_WATER_TEMPERATURE = "modbuslink:MiddleWaterTemperatureState"
+    MODBUSLINK_NUMBER_CONTROL_SHOWER_REQUEST = (
+        "modbuslink:NumberControlShowerRequestState"
+    )
+    MODBUSLINK_OPERATING_RANGE = "modbuslink:OperatingRangeState"
+    MODBUSLINK_POWER_HEAT_ELECTRICAL = "modbuslink:PowerHeatElectricalState"
+    MODBUSLINK_POWER_HEAT_PUMP = "modbuslink:PowerHeatPumpState"
+    MODBUSLINK_PROGRAMMING_SLOTS = "modbuslink:ProgrammingSlotsState"
+    MODBUSLINK_SMART_GRID_OPTION = "modbuslink:SmartGridOptionState"
     MODBUS_CONTROL_DHW = "modbus:ControlDHWState"
     MODBUS_CONTROL_DHW_SETTING_TEMPERATURE = "modbus:ControlDHWSettingTemperatureState"
     MODBUS_DHW_MODE = "modbus:DHWModeState"
